@@ -178,6 +178,20 @@ to the built-in default sites without asking? (yes/no)?
 Shall we always set the FTP_PASSIVE environment variable when dealing
 with ftp download (yes/no)?
 
+=item ftpstats_period
+
+Statistics about downloads are truncated by size and period
+simultaneously.
+
+How many days shall we keep statistics about downloads?
+
+=item ftpstats_size
+
+Statistics about downloads are truncated by size and period
+simultaneously.
+
+How many items shall we keep in the statistics about downloads?
+
 =item getcwd
 
 CPAN.pm changes the current working directory often and needs to
@@ -1195,6 +1209,12 @@ substitute. You can then revisit this dialog with
         if ("randomize_urllist" =~ $matcher) {
             my_dflt_prompt(randomize_urllist => 0, $matcher);
         }
+        if ("ftpstats_size" =~ $matcher) {
+            my_dflt_prompt(ftpstats_size => 99, $matcher);
+        }
+        if ("ftpstats_period" =~ $matcher) {
+            my_dflt_prompt(ftpstats_period => 14, $matcher);
+        }
     } elsif ($fastread) {
         $CPAN::Frontend->myprint("Autoconfigured everything but 'urllist'.\n".
                                  "Please call 'o conf init urllist' to configure ".
@@ -1216,7 +1236,6 @@ sub my_dflt_prompt {
     my ($item, $dflt, $m) = @_;
     my $default = $CPAN::Config->{$item} || $dflt;
 
-    $DB::single = 1;
     if (!$m || $item =~ /$m/) {
         if (my $intro = $prompts{$item . "_intro"}) {
             $CPAN::Frontend->myprint($intro);
@@ -1253,7 +1272,6 @@ sub my_prompt_loop {
     my $default = $CPAN::Config->{$item} || $dflt;
     my $ans;
 
-    $DB::single = 1;
     if (!$m || $item =~ /$m/) {
         $CPAN::Frontend->myprint($prompts{$item . "_intro"});
         $CPAN::Frontend->myprint(" <$item>\n");
